/* === This file is part of Calamares - <https://calamares.io> ===
 *
 *   SPDX-FileCopyrightText: 2014 Teo Mrnjavac <teo@kde.org>
 *   SPDX-License-Identifier: GPL-3.0-or-later
 *
 *   Calamares is Free Software: see the License-Identifier above.
 *
 */

#ifndef LIBCALAMARESUI_TMAXOSPROGRESSBAR_H
#define LIBCALAMARESUI_TMAXOSPROGRESSBAR_H

#include "DllMacro.h"

#include <QProgressBar>
#include <QPaintEvent>

class QHBoxLayout;
class QWidget;

namespace Calamares
{
class TmaxOsLabel;

class UIDLLEXPORT TmpProgressBar : public QProgressBar
{
    Q_OBJECT
public:
    explicit TmpProgressBar( QWidget* parent = nullptr );

    void setValue( int value );
    void updateLabelPosition();

Q_SIGNALS:
    void positionMoved( int pixels );

protected:
    void paintEvent( QPaintEvent* e );

protected:
    int m_lastPaintedValue = -1;
    int m_moved = 0;
};

class UIDLLEXPORT TmaxOsProgressBar : public QWidget
{
    Q_OBJECT
public:
    explicit TmaxOsProgressBar( QWidget* parent = nullptr );

    void setValue( int value );
    void setText( const QString& text, int lineheight = 17 );
    void setMaximum( int maximum ) { m_progressBar->setMaximum( maximum ); }
    void setMinimum( int minimum ) { m_progressBar->setMinimum( minimum ); }
    int maximum() const { return m_progressBar->maximum(); }
    int minimum() const { return m_progressBar->minimum(); }

public Q_SLOTS:
    void updateLabel( int pixels );

protected:
    TmpProgressBar* m_progressBar;
    QWidget* m_movingProgressBarLabel;
    QHBoxLayout* m_movingProgressBarLabelLayout;
    TmaxOsLabel* m_roundedText;
};

}  // namespace Calamares
#endif  // LIBCALAMARESUI_TMAXOSPROGRESSBAR_H
