#!/usr/bin/env python3
# -*- coding: utf-8 -*-
#
# === This file is part of Calamares - <https://calamares.io> ===
#
#   SPDX-FileCopyrightText: 2014-2015 Philip Müller <philm@manjaro.org>
#   SPDX-FileCopyrightText: 2015-2017 Teo Mrnjavac <teo@kde.org>
#   SPDX-FileCopyrightText: 2017 Alf Gaida <agaida@siduction.org>
#   SPDX-FileCopyrightText: 2017 2019, Adriaan de Groot <groot@kde.org>
#   SPDX-FileCopyrightText: 2017-2018 Gabriel Craciunescu <crazy@frugalware.org>
#   SPDX-License-Identifier: GPL-3.0-or-later
#
#   Calamares is Free Software: see the License-Identifier above.
#

import libcalamares
import os
import re

import gettext
_ = gettext.translation("calamares-python",
                        localedir=libcalamares.utils.gettext_path(),
                        languages=libcalamares.utils.gettext_languages(),
                        fallback=True).gettext

def pretty_name():
    return _("TmaxOsGpmsJoin")

def isExists(path):
    root_mount_point = libcalamares.globalstorage.value("rootMountPoint")
    while os.path.islink(path):
        path = "{0}{1}".format(root_mount_point, os.path.realpath(path))
    if os.path.exists(path):
        return True
    else:
        return False

def gpmsJoinErrors():
    root_mount_point = libcalamares.globalstorage.value("rootMountPoint")

    ROOT_PEM = libcalamares.job.configuration.get("root-pem")
    ROOT_CERT = libcalamares.job.configuration.get("root-cert")
    CLIENT_CERT = libcalamares.job.configuration.get("client-cert")
    GOOROOM_CLIENT_KEY = libcalamares.job.configuration.get("gooroom-client-key")
    GOOROOM_PUBLIC_KEY = libcalamares.job.configuration.get("gooroom-public-key")
    GOOROOM_SERVER_KEY = libcalamares.job.configuration.get("gooroom-server-key")
    GCSR_CONF = libcalamares.job.configuration.get("gcsr-conf")
    GCSR_MASTER_CONF = libcalamares.job.configuration.get("gcsr-master-conf")
    GCSR_SLAVE_CONF = libcalamares.job.configuration.get("gcsr-slave-conf")

    root_pem_path = os.path.join(root_mount_point, ROOT_PEM)
    root_cert_path = os.path.join(root_mount_point, ROOT_CERT)
    client_cert_path = os.path.join(root_mount_point, CLIENT_CERT)
    gooroom_client_key_path = os.path.join(root_mount_point, GOOROOM_CLIENT_KEY)
    gooroom_public_key_path = os.path.join(root_mount_point, GOOROOM_PUBLIC_KEY)
    gooroom_server_key_path = os.path.join(root_mount_point, GOOROOM_SERVER_KEY)
    gcsr_conf_path = os.path.join(root_mount_point, GCSR_CONF)
    gcsr_master_conf_path = os.path.join(root_mount_point, GCSR_MASTER_CONF)
    gcsr_slave_conf_path = os.path.join(root_mount_point, GCSR_SLAVE_CONF)

    paths = []
    paths.append(root_pem_path)
    paths.append(root_cert_path)
    paths.append(client_cert_path)
    paths.append(gooroom_client_key_path)
    paths.append(gooroom_public_key_path)
    paths.append(gooroom_server_key_path)
    paths.append(gcsr_conf_path)
    paths.append(gcsr_master_conf_path)
    paths.append(gcsr_slave_conf_path)

    errors = []
    for path in paths:
        if not isExists(path):
            errors.append("{}".format(path))
    return errors

def gpmsJoin():
    """
    Join GPMS.
    """
    # get hostname that set in the tmaxosusers module
    hostName = libcalamares.globalstorage.value("hostname")

    # get GPMS server related values from gpmscfg.conf
    serverIpAddr = libcalamares.job.configuration.get("server-ip-addr")
    gkmDomain = libcalamares.job.configuration.get("gkm-domain")
    glmDomain = libcalamares.job.configuration.get("glm-domain")
    gpmsDomain = libcalamares.job.configuration.get("gpms-domain")
    grmDomain = libcalamares.job.configuration.get("grm-domain")
    defaultGroup = libcalamares.job.configuration.get("default-group")
    superId = libcalamares.job.configuration.get("super-id")
    superPassword = libcalamares.job.configuration.get("super-password")

    # write domain info in /etc/hosts of root mount point
    libcalamares.utils.target_env_call(["sh", "-c", "echo '{0} {1}' >> /etc/hosts".format(serverIpAddr, gkmDomain)])
    libcalamares.utils.target_env_call(["sh", "-c", "echo '{0} {1}' >> /etc/hosts".format(serverIpAddr, glmDomain)])
    libcalamares.utils.target_env_call(["sh", "-c", "echo '{0} {1}' >> /etc/hosts".format(serverIpAddr, gpmsDomain)])
    libcalamares.utils.target_env_call(["sh", "-c", "echo '{0} {1}' >> /etc/hosts".format(serverIpAddr, grmDomain)])

    # Try GPMS join
    errors = []
    # gooroom-client-server-register noninteractive -d {gkmDomain} -n {hostName} -u {defaultGroup} -i {superId} -p {superPassword}
    libcalamares.utils.target_env_call(["sh", "-c", "gooroom-client-server-register noninteractive -d {0} -n {1} -u {2} -i {3} -p {4}".format(gkmDomain, hostName, defaultGroup, superId, superPassword)])

    # GPMS join failure check
    #  check whether all necessary files exist
    errors = gpmsJoinErrors()

    if errors:
        return (_("Retry button to reconfigure network"),
                _("Error: gpms join file not found\n{}".format("\n".join(errors))))
    return None

def run():
    return gpmsJoin()
