#!/usr/bin/env python3
# -*- coding: utf-8 -*-

import libcalamares
import os
import re
from libcalamares.utils import check_target_env_output, target_env_call, debug
from pprint import pprint

import gettext
_ = gettext.translation("calamares-python",
                        localedir=libcalamares.utils.gettext_path(),
                        languages=libcalamares.utils.gettext_languages(),
                        fallback=True).gettext

def pretty_name():
    return _("Configure tmaxossecurity")

def install_pkg(package_name):
    aptComm = ["env", "DEBIAN_FRONTEND=noninteractive", "apt-get", "--option=Dpkg::Options::=--force-confdef", "-y", "install"]
    ret = check_target_env_output(aptComm + [package_name])

    return None

def change_local_settings():
    rootDev = libcalamares.globalstorage.value("rootDevice")
    swapDev = libcalamares.globalstorage.value("swapDevice")
    rootUUID = "e90c3c12-2f09-4740-a633-21c40670c4fb"
    swapUUID = "d562bac6-ce74-4a5d-b565-c3d328d71976"

    cryptComm = ["cryptsetup", "-q", "--uuid"]
    libcalamares.utils.target_env_call(cryptComm + [rootUUID, "luksUUID", rootDev])
    libcalamares.utils.target_env_call(cryptComm + [swapUUID, "luksUUID", swapDev])

    chroot = libcalamares.globalstorage.value("rootMountPoint")
    # modify /etc/fstab
    with open(chroot + "/etc/fstab", "r+") as f:
        lines = f.readlines()
        f.seek(0)
        for line in lines:
            if "luks-" not in line:
                f.write(line)
        f.truncate()
        f.write("/dev/mapper/luks-root / ext4 defaults,noatime 0 1\n")
        f.write("/dev/mapper/luks-swap swap swap defaults,noatime 0 0\n")

    # modify /etc/crypttab
    with open(chroot + "/etc/crypttab", "w") as f:
        line = "luks-root UUID={} none luks,keyscript=/lib/cryptsetup/scripts/decrypt_keyctl\n"
        f.write(line.format(rootUUID))
        f.write(line.format(swapUUID))

    # modify /etc/initramfs-tools/conf.d/resume
    with open(chroot + "/etc/initramfs-tools/conf.d/resume", "w") as f:
        f.write("RESUME=/dev/mapper/luks-swap\n")

    # modify /etc/default/grub
    with open(chroot + "/etc/default/grub", "r+") as f:
        lines = f.readlines()
        f.seek(0)
        for line in lines:
            if "GRUB_CMDLINE_LINUX_DEFAULT" in line:
                f.write("GRUB_CMDLINE_LINUX_DEFAULT=\"quiet splash resume=/dev/mapper/luks-swap\"\n")
            elif "#GRUB_DISABLE_LINUX_UUID" in line:
                f.write("GRUB_DISABLE_LINUX_UUID=true\n")
            else:
                f.write(line)
        f.truncate()

    return None

def run():
    if libcalamares.job.configuration.get("apply_exe_prot", False):
        install_pkg("tmaxgooroom-exe-protector")

    if libcalamares.job.configuration.get("apply_boot_prot", False):
        install_pkg("tmaxgooroom-boot-protector")

    if libcalamares.globalstorage.value("fdeApplied"):
        change_local_settings()

    return None
